aboutsummaryrefslogtreecommitdiffstats
path: root/src/gevent/gevent.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gevent/gevent.h')
-rw-r--r--src/gevent/gevent.h16
1 files changed, 4 insertions, 12 deletions
diff --git a/src/gevent/gevent.h b/src/gevent/gevent.h
index 8b95235d..121895ba 100644
--- a/src/gevent/gevent.h
+++ b/src/gevent/gevent.h
@@ -77,10 +77,6 @@ typedef struct GSourceListener_t {
/* External declarations. */
/*===========================================================================*/
-#ifdef __cplusplus
-extern "C" {
-#endif
-
/* How to listen for events (act as a Listener)...
1. Get handles for all the event sources you are interested in.
2. Initialise a listener
@@ -97,7 +93,7 @@ extern "C" {
For each listener - check the flags to see if an event should be sent.
- use geventGetEventBuffer() to get the event buffer supplied by the listener
and then call geventSendEvent() to send the event.
- - Note: geventGetEventBuffer() may return FALSE to indicate the listener is currently not listening and
+ - Note: geventGetEventBuffer() may return gFalse to indicate the listener is currently not listening and
therefore no event should be sent. This situation enables the source to (optionally) flag
to the listener on its next wait that there have been missed events.
- Note: The GSourceListener pointer (and the GEvent buffer) are only valid between
@@ -121,16 +117,16 @@ void geventListenerInit(GListener *pl);
* @brief Attach a source to a listener
* @details Flags are interpreted by the source when generating events for each listener.
* If this source is already assigned to the listener it will update the flags.
* If insufficient resources are available it will either assert or return FALSE
* depending on the value of GEVENT_ASSERT_NO_RESOURCE.
*
* @param[in] pl The listener
* @param[in] gsh The source which has to be attached to the listener
* @param[in] flags The flags
*
* @return TRUE if succeeded, FALSE otherwise
*/
-bool_t geventAttachSource(GListener *pl, GSourceHandle gsh, uint32_t flags);
+gBool geventAttachSource(GListener *pl, GSourceHandle gsh, uint32_t flags);
/**
* @brief Detach a source from a listener
@@ -236,10 +232,6 @@ void geventSendEvent(GSourceListener *psl);
*/
void geventDetachSourceListeners(GSourceHandle gsh);
-#ifdef __cplusplus
-}
-#endif
-
#endif /* GFX_USE_GEVENT */
#endif /* _GEVENT_H */
@@ -121,16 +117,16 @@ void geventListenerInit(GListener *pl);
* @details Flags are interpreted by the source when generating events for each listener.
* If this source is already assigned to the listener it will update the flags.
- * If insufficient resources are available it will either assert or return FALSE
+ * If insufficient resources are available it will either assert or return gFalse
* depending on the value of GEVENT_ASSERT_NO_RESOURCE.
*
@@ -121,16 +117,16 @@ void geventListenerInit(GListener *pl);
* @param[in] flags The flags
*
- * @return TRUE if succeeded, FALSE otherwise
+ * @return gTrue if succeeded, gFalse otherwise
*/